// Copyright 2009-present MongoDB, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include <mongocxx/options/pool.hpp>

namespace mongocxx {
namespace v_noabi {
namespace options {

pool::pool(client client_opts) : _client_opts(std::move(client_opts)) {}

client const& pool::client_opts() const {
    return _client_opts;
}

} // namespace options
} // namespace v_noabi
} // namespace mongocxx
